.mode tabs
.echo off
-- Average CO2 emissions
.output average.txt
select avg(CO2) from papers where CO2 notnull;

-- CO2 emissions by author country
.output all-countries.txt
select Locations.cc1, Divisions.name, avg(CO2), count(*), Locations.lat, Locations.long from Papers
inner join Locations on Papers.corrLocId = Locations.id
inner Join Divisions on Locations.cc1 = Divisions.country
where Divisions.code = '00' and CO2 notnull
group by Locations.cc1
having count(*) > 20
order by avg(CO2) asc;

-- Worst average CO2 emissions by conference location
.output bad-conf-locations.txt
select names.name, Locations.cc1, avg(CO2), count(*) from Papers
inner join Locations on Papers.confLocId = Locations.id
inner join Names on Locations.Nameid = Names.id
where CO2 notnull
group by Locations.id
having count(*) > 20
order by avg(CO2) desc limit 10;


-- Best average CO2 emissions by conference location
.output good-conf-locations.txt
select names.name, Locations.cc1, avg(CO2), count(*) from Papers
inner join Locations on Papers.confLocId = Locations.id
inner join Names on Locations.Nameid = Names.id
where CO2 notnull
group by Locations.id
having count(*) > 20
order by avg(CO2) asc limit 10;

-- Average CO2 emissions by conference location
.output all-conf-locations.txt
select names.name, Locations.cc1, avg(CO2), count(*), Locations.lat, Locations.long from Papers
inner join Locations on Papers.confLocId = Locations.id
inner join Names on Locations.Nameid = Names.id
where CO2 notnull
group by Locations.id
having count(*) > 20
order by avg(CO2) asc;

-- Worst average CO2 emissions by conference country
.output bad-conf-countries.txt
select Divisions.name, avg(CO2), count(*) from Papers
inner join Locations on Papers.confLocId = Locations.id
inner Join Divisions on Locations.cc1 = Divisions.country
where Divisions.code = '00' and CO2 notnull
group by Locations.cc1
having count(*) > 20
order by avg(CO2) desc limit 10;

-- Best average CO2 emissions by conference country
.output good-conf-countries.txt
select Divisions.name, avg(CO2), count(*) from Papers
inner join Locations on Papers.confLocId = Locations.id
inner Join Divisions on Locations.cc1 = Divisions.country
where Divisions.code = '00' and CO2 notnull
group by Locations.cc1
having count(*) > 20
order by avg(CO2) asc limit 10;

-- Average CO2 emissions by conference country
.output all-conf-countries.txt
select Locations.cc1, Divisions.name, avg(CO2), count(*), Locations.lat, Locations.long from Papers
inner join Locations on Papers.confLocId = Locations.id
inner Join Divisions on Locations.cc1 = Divisions.country
where Divisions.code = '00' and CO2 notnull
group by Locations.cc1
having count(*) > 20
order by avg(CO2) desc;

-- Worst average CO2 emissions by conference administrative division (state etc)
.output bad-conf-regions.txt
select pDivisions.name, cDivisions.name, avg(CO2), count(*)
from Papers
left join Locations on Papers.confLocId = Locations.id
left Join Divisions as pDivisions on Locations.cc1 = pDivisions.country and
	     Locations.adm1 = pDivisions.code
left join Divisions as cDivisions on Locations.cc1 = cDivisions.country
where cDivisions.code = '00' and CO2 notnull
group by pDivisions.country, pDivisions.code
having count(*) > 20
order by avg(CO2) desc limit 10;

-- All average CO2 emissions by conference administrative division (state etc)
.output all-conf-regions.txt
select pDivisions.name, cDivisions.name, avg(CO2), count(*), Locations.lat, Locations.long
from Papers
left join Locations on Papers.confLocId = Locations.id
left Join Divisions as pDivisions on Locations.cc1 = pDivisions.country and
	     Locations.adm1 = pDivisions.code
left join Divisions as cDivisions on Locations.cc1 = cDivisions.country
where cDivisions.code = '00' and CO2 notnull
group by pDivisions.country, pDivisions.code
having count(*) > 20
order by avg(CO2) desc;

-- CO2 emissions of the most popular locations
.output popular-locations.txt
select Names.name, Locations.cc1, count(Locations.id), avg(CO2)
from Papers
left join Locations on Papers.confLocId = Locations.id
left join Names on Names.id = Locations.NameId
where CO2 notnull
group by Locations.id order by count(Locations.id) desc limit 10;

-- Conference duration
--select julianday(edate)-julianday(bdate) from papers;

-- Papers by publisher
.output publishers.txt
select count(doi.prefix), publisher from papers inner join doi on
substr(papers.doi, 4, 4) = doi.prefix
where papers.doi notnull group by doi.prefix
order by count(doi.prefix);

-- CO2 by publisher
.output publishers.txt
select avg(CO2), publisher, count(*) from papers inner join doi on
substr(papers.doi, 4, 4) = doi.prefix
where papers.CO2 notnull and papers.doi notnull
group by doi.prefix
having count(*) > 20
order by avg(CO2);

-- Lowest CO2 by sponsor
.output good-sponsors.txt
select sponsors.name, avg(CO2), count(*) from PaperSponsors
inner join Papers on PaperId = papers.id
inner join Sponsors on SponsorId = Sponsors.id
where papers.CO2 notnull
group by sponsors.id
having count(*) > 20
order by avg(CO2) asc limit 10;

-- Highest CO2 by sponsor
.output bad-sponsors.txt
select sponsors.name, avg(CO2), count(*) from PaperSponsors
inner join Papers on PaperId = papers.id
inner join Sponsors on SponsorId = Sponsors.id
where papers.CO2 notnull
group by sponsors.id
having count(*) > 20
order by avg(CO2) desc limit 10;

-- CO2 by conference year (only the CO2)
.output years.txt
select avg(CO2) from
Papers
where bDate notnull and strftime("%Y", bDate) > "1997" and CO2 notnull
group by strftime("%Y", bDate)
order by strftime("%Y", bDate);

-- CO2 by conference year (all details)
.output fullyears.txt
select strftime("%Y", bDate) as year, avg(CO2), count(*) from
Papers
where bDate notnull and year > "1997" and CO2 notnull
group by year
order by year;

-- CO2 by conference month
.output months.txt
select strftime("%m", bDate) as month, count(*),
avg(CO2), sum(CO2)
from Papers
where bDate notnull and CO2 notnull
group by month
order by month;

-- Worst country pairs
.output bad-country-pairs.txt
select aw.cc1, cw.cc1, count(*), avg(CO2), sum(CO2) / 1000
from Papers
inner join Locations as cw on Papers.confLocId = cw.id
inner join Locations as aw on Papers.corrLocId = aw.id
where CO2 notnull
group by aw.cc1, cw.cc1
order by sum(CO2) desc
limit 10;

-- Worst US state pairs
.output bad-state-pairs.txt
select aw.adm1, cw.adm1, count(*), avg(CO2), sum(CO2)
from Papers
inner join Locations as cw on Papers.confLocId = cw.id
inner join Locations as aw on Papers.corrLocId = aw.id
where cw.cc1 = 'US' and aw.cc1 = 'US' and CO2 notnull
group by aw.adm1, cw.adm1
order by sum(CO2) desc
limit 10;


-- Most popular country pairs
.output popular-country-pairs.txt
select aw.cc1, cw.cc1, count(*), avg(CO2), sum(CO2) / 1000
from Papers
inner join Locations as cw on Papers.confLocId = cw.id
inner join Locations as aw on Papers.corrLocId = aw.id
where CO2 notnull
group by aw.cc1, cw.cc1
order by count(*) desc
limit 10;

-- Most popular US state pairs
.output popular-state-pairs.txt
select aw.adm1, cw.adm1, count(*), avg(CO2), sum(CO2)
from Papers
inner join Locations as cw on Papers.confLocId = cw.id
inner join Locations as aw on Papers.corrLocId = aw.id
where cw.cc1 = 'US' and aw.cc1 = 'US' and CO2 notnull
group by aw.adm1, cw.adm1
order by count(*) desc
limit 10;

.output stdout
